********************************************************************************
*																			   *
*           Maternal Mental Health and its influence on Children's             *
*           Early Development: Evidence from Khyber Pakhtunkhwa, Pakistan	   *
*													                           *
*																			   *
*           Stata .do file 1: Clean and Format data for Stata  				   *
*																			   *
********************************************************************************

************
* Clean and format KP HH Survey Data
************

use "$data/KP survey_raw.dta", clear
	
	*Merge with CREDI scores
	merge 1:1 ID using "$data/CREDI.dta"

	* Generate age category variable
	gen agegroup=0
	replace agegroup=1 if AGE<36
	replace agegroup=2 if AGE>=36
	replace agegroup=. if AGE==.

	tab agegroup, missing
	
	label var agegroup "Child age category"
	label define agegroup 1 "0-35 mos" 2 "36-72 mos"
	label val agegroup agegroup
	
	*Generate rural/urban variable
	gen rural=0
	replace rural=1 if location==3
	replace rural=. if location==.

	tab rural, missing
	
	label var rural "Lives in rural area"
	label define rural 0 "Urban" 1 "Rural"
	label val rural rural
	
	*Generate maternal education variable
	 gen maternal_ed= edu_highest_1 if resp_id==1
	replace maternal_ed=edu_highest_2 if resp_id==2
	replace maternal_ed=edu_highest_3 if resp_id==3
	replace maternal_ed=edu_highest_4 if resp_id==4
	replace maternal_ed=edu_highest_5 if resp_id==5
	replace maternal_ed=edu_highest_6 if resp_id==6
	replace maternal_ed=edu_highest_7 if resp_id==7
	replace maternal_ed=edu_highest_8 if resp_id==8
	replace maternal_ed=edu_highest_9 if resp_id==9
	replace maternal_ed=edu_highest_10 if resp_id==10
	replace maternal_ed=edu_highest_11 if resp_id==11
	replace maternal_ed=edu_highest_12 if resp_id==12
	replace maternal_ed=edu_highest_13 if resp_id==13
	replace maternal_ed=edu_highest_14 if resp_id==14
	replace maternal_ed=edu_highest_15 if resp_id==15
	replace maternal_ed=edu_highest_16 if resp_id==16
	replace maternal_ed=edu_highest_17 if resp_id==17
	replace maternal_ed=edu_highest_18 if resp_id==18
	replace maternal_ed=edu_highest_19 if resp_id==19
	replace maternal_ed=edu_highest_20 if resp_id==20
	replace maternal_ed=edu_highest_21 if resp_id==21
	replace maternal_ed=edu_highest_22 if resp_id==22
	replace maternal_ed=edu_highest_23 if resp_id==23
	replace maternal_ed=edu_highest_24 if resp_id==24
	replace maternal_ed=edu_highest_25 if resp_id==25
	replace maternal_ed=edu_highest_26 if resp_id==26
	replace maternal_ed=edu_highest_27 if resp_id==27
 
   gen maternal_ed_cat1=1 if maternal_ed==. 
  replace maternal_ed_cat1=2 if maternal_ed==25 | maternal_ed==27 | maternal_ed==26 | maternal_ed==29 | (maternal_ed>=1 & maternal_ed<=4)
 replace maternal_ed_cat1=3 if maternal_ed>=5 & maternal_ed<=7
 replace maternal_ed_cat1=4 if maternal_ed>=8 & maternal_ed<=10
 replace maternal_ed_cat1=5 if maternal_ed>=11 & maternal_ed<=12
 replace maternal_ed_cat1=6 if maternal_ed==13 | maternal_ed==14 | maternal_ed==15 | maternal_ed==20 | maternal_ed==21 | maternal_ed==18
 replace maternal_ed_cat1=7 if maternal_ed==16 | maternal_ed==22 | maternal_ed==24
 replace maternal_ed_cat1=8 if maternal_ed==97
 
	tab maternal_ed_cat1, missing
	
	label var maternal_ed_cat1 "Maternal Education"
	label define maternal_ed_cat1 1 "No education" 2 "Completed pre-primary" 3 "Completed primary" 4 "Completed middle" 5 "Completed secondary" 6 "Completed bachelor's degree" 7 "Completed graduate degree" 8 "Religious education"
	label val maternal_ed_cat1 maternal_ed_cat1
	
	*Generate primary education dichotomous variable
	gen primary_ed=0 if maternal_ed_cat1==8 | maternal_ed_cat1==1 | maternal_ed_cat1==2
	replace primary_ed=1 if maternal_ed_cat1>=3 & maternal_ed_cat1<=7
	
	label var primary_ed "Completed Primary Education"
	label define primary_ed 0 "No" 1 "Yes"
	label val primary_ed primary_ed
	
	*Generate maternal age
	gen maternal_age= age_years_1 if resp_id==1
	replace maternal_age=age_years_2 if resp_id==2
	replace maternal_age=age_years_3 if resp_id==3
	replace maternal_age=age_years_4 if resp_id==4
	replace maternal_age=age_years_5 if resp_id==5
	replace maternal_age=age_years_6 if resp_id==6
	replace maternal_age=age_years_7 if resp_id==7
	replace maternal_age=age_years_8 if resp_id==8
	replace maternal_age=age_years_9 if resp_id==9
	replace maternal_age=age_years_10 if resp_id==10
	replace maternal_age=age_years_11 if resp_id==11
	replace maternal_age=age_years_12 if resp_id==12
	replace maternal_age=age_years_13 if resp_id==13
	replace maternal_age=age_years_14 if resp_id==14
	replace maternal_age=age_years_15 if resp_id==15
	replace maternal_age=age_years_16 if resp_id==16
	replace maternal_age=age_years_17 if resp_id==17
	replace maternal_age=age_years_18 if resp_id==18
	replace maternal_age=age_years_19 if resp_id==19
	replace maternal_age=age_years_20 if resp_id==20
	replace maternal_age=age_years_21 if resp_id==21
	replace maternal_age=age_years_22 if resp_id==22
	replace maternal_age=age_years_23 if resp_id==23
	replace maternal_age=age_years_24 if resp_id==24
	replace maternal_age=age_years_25 if resp_id==25
	replace maternal_age=age_years_26 if resp_id==26
	replace maternal_age=age_years_27 if resp_id==27
	
	label var maternal_age "Maternal Age"
	
	*Generate household head age
	gen hh_age= age_years_1 if relation_1==1
	replace hh_age= age_years_2 if relation_2==1
	replace hh_age= age_years_3 if relation_3==1 & hh_age==.
	replace hh_age= age_years_4 if relation_4==1 & hh_age==.
	replace hh_age= age_years_5 if relation_5==1 & hh_age==.
	replace hh_age= age_years_6 if relation_6==1 & hh_age==.
	replace hh_age= age_years_7 if relation_7==1 & hh_age==.
	replace hh_age= age_years_8 if relation_8==1 & hh_age==.
	replace hh_age= age_years_9 if relation_9==1 & hh_age==.
	replace hh_age= age_years_11 if relation_11==1 & hh_age==.
	replace hh_age= age_years_12 if relation_12==1 & hh_age==.
	replace hh_age= age_years_13 if relation_13==1 & hh_age==.
	replace hh_age= age_years_14 if relation_14==1 & hh_age==.
	replace hh_age= age_years_26 if relation_26==1 & hh_age==.
	
	label var hh_age "Head of Household Age"
	
	*Generate enrollment in ECE
	gen attend_ece=1 if hours_sch!=.
	replace attend_ece=0 if (hours_sch==. & AGE>=36)
	
	label var attend_ece "ECE Attendance"
	label define attend_ece 0 "Does not attend" 1 "Attends"
	label val attend_ece attend_ece
	
	*Generate current class variables
	*ece variable
	gen child_ed1= edu_current_1 if child_id==1
	replace child_ed1=edu_current_2 if child_id==2
	replace child_ed1=edu_current_3 if child_id==3
	replace child_ed1=edu_current_4 if child_id==4
	replace child_ed1=edu_current_5 if child_id==5
	replace child_ed1=edu_current_6 if child_id==6
	replace child_ed1=edu_current_7 if child_id==7
	replace child_ed1=edu_current_8 if child_id==8
	replace child_ed1=edu_current_9 if child_id==9
	replace child_ed1=edu_current_10 if child_id==10
	replace child_ed1=edu_current_11 if child_id==11
	replace child_ed1=edu_current_12 if child_id==12
	replace child_ed1=edu_current_13 if child_id==13
	replace child_ed1=edu_current_14 if child_id==14
	replace child_ed1=edu_current_15 if child_id==15
	replace child_ed1=edu_current_16 if child_id==16
	replace child_ed1=edu_current_17 if child_id==17
	replace child_ed1=edu_current_18 if child_id==18
	replace child_ed1=edu_current_19 if child_id==19
	replace child_ed1=edu_current_20 if child_id==20
	replace child_ed1=edu_current_21 if child_id==21
	replace child_ed1=edu_current_22 if child_id==22
	replace child_ed1=edu_current_23 if child_id==23
	replace child_ed1=edu_current_24 if child_id==24
	replace child_ed1=edu_current_25 if child_id==25
	replace child_ed1=edu_current_26 if child_id==26
	replace child_ed1=edu_current_27 if child_id==27
	
	list child_ed1 if attend_ece==1 & AGE>=36

	gen current_class_update= current_class
	replace current_class_update= child_ed1 if (current_class==. & AGE>=36)
	tab current_class_update
	replace current_class_update=. if current_class_update==0
	replace current_class_update=0 if attend_ece==1 & current_class_update==.
	
	label var current_class_update "ECE Class"
	label define current_class_update 0 "Missing/Other" 1 "Class 1" 2 "Class 2" 5 "Class 5" 25 "Playgroup" 26 "Nursery" 27 "Prep" 28 "Other ECE" 29 "Katchi" 30 "Kindergarten" 97 "Other"
	label val current_class_update current_class_update
	
	*Generate less categories for ECE variable
	gen current_class_final= 1 if current_class_update==25
	replace current_class_final= 2 if current_class_update==26
	replace current_class_final= 3 if current_class_update==29
	replace current_class_final= 4 if attend_ece==1 & current_class_final==.
	
	label var current_class_final "ECE Class Simplified"
	label define current_class_final 1 "Playgroup" 2 "Nursery" 3 "Katchi" 4 "Other ECE/Missing" 
	label val current_class_final current_class_final
	
	*Fix attend ECE variable
	replace attend_ece=1 if current_class_update!=.
	
	*Generate school Type
	*public school status (1=govt, 2=private, 3= deeni madaris, 5= non-formal basic ed, 6= distance ed, 7= raha schools)
	gen sch_type_update=sch_type_child
	replace sch_type_update= 3 if sch_type_child>=3 & sch_type_child<=6
	replace sch_type_update= 3 if attend_ece==1 & sch_type_child==.

	label var sch_type_update "School Type"
	label define sch_type_update 1 "Government" 2 "Private" 3 "Other" 7 "Refugee School" 
	label val sch_type_update sch_type_update	
 
	*Generate days per week attend ece variable
	gen daysperweek= 1 if days_weekly_sch<=3
	replace daysperweek= 2 if days_weekly_sch>=4 & days_weekly_sch<=5
	replace daysperweek= 3 if days_weekly_sch==6

	label var daysperweek "Frequency of ECE Attendance (days/week)"
	label define daysperweek 1 "1-3 days" 2 "4-5 days" 3 "6 days" 
	label val daysperweek daysperweek		

	*Generate hours per day attend ece variable
	gen hoursperday= 1 if hours_sch<=3
	replace hoursperday= 2 if hours_sch>=4 & hours_sch<=5
	replace hoursperday= 3 if hours_sch==6

	label var hoursperday "Frequency of ECE Attendance (hours/day)"
	label define hoursperday 1 "1-3 hours" 2 "4-5 hours" 3 "6+ hours" 
	label val hoursperday hoursperday
	
	*Generate flood exposure in 2022 or 2023
	gen flood_impact_gen=0
	replace flood_impact_gen=1 if floods_2023_8==0 | floods_2022_8==0
	label var flood_impact_gen "Impacted by Flooding in 2022 or 2023"
	label define flood_impact_gen 0 "No" 1 "Yes"
	label val flood_impact_gen flood_impact_gen
	tab flood_impact_gen
	
	*Generate flood exposure in 2023
	gen flood_2023_impact=0
	replace flood_2023_impact=1 if floods_2023_8==0
	label var flood_2023_impact "Impacted by Flooding in 2023"
	label define flood_2023_impact 0 "No" 1 "Yes"
	label val flood_2023_impact flood_2023_impact
	tab flood_2023_impact

	*Generate flood exposure in 2022
	gen flood_2022_impact=0
	replace flood_2022_impact=1 if floods_2022_8==0
	label var flood_2022_impact "Impacted by Flooding in 2022"
	label define flood_2022_impact 0 "No" 1 "Yes"
	label val flood_2022_impact flood_2022_impact
	tab flood_2022_impact

	*Generate experiences of discrimination variable 
	gen any_discrim=0
	replace any_discrim=1 if discrim_religion==1 | discrim_ethnic==1 |  discrim_immigration==1 |  discrim_sex==1 |  discrim_sexual_orientation==1 |  discrim_age==1 |  discrim_religion==1 | discirm_disability==1 | discrimination_reason==1 

	label var any_discrim "Experienced Discrimination"
	label define any_discrim 0 "No" 1 "Yes"
	label val any_discrim any_discrim
	tab any_discrim
	
	*Generate Depression Continuous
	gen depress_cont= headaches+poor_appetite+bad_sleep+easily_frightened+shaky_hands+nervousness+poor_digestion+trouble_thinking+unhappiness+frequent_crying+difficulty_enjoying_activities+decision_making+work_impact+feeling_useless+loss_of_interest+worthlessness+suicidal_thoughts+chronic_fatigue+stomach_discomfort+easily_tired
	label var depress_cont "Depression Continuous Score"

	*Generate Depression Dichotomous
	gen depress=0
	replace depress=1 if depress_cont>=9
	label var depress "Experienced Depression"
	label define depress 0 "No" 1 "Yes"
	label val depress depress
	tab depress
	
	*Generate anxiety continuous
	gen anxiety_cont= mental_health_issues+anxiety_symptoms+worrying+trouble_relaxing+restlessness+irritability+fearfulness 
	label var anxiety_cont "Anxiety Continuous Score"
	
	*Generate anxiety dichotomous
	gen anxiety=0
	replace anxiety=1 if anxiety_cont>=5 & anxiety_cont<=9
	replace anxiety=2 if anxiety_cont>=10 & anxiety_cont<=14
	replace anxiety=3 if anxiety_cont>=15
	label var anxiety "Experienced Anxiety"
	label define anxiety 0 "Minimal Anxiety" 1 "Mild Anxiety" 2 "Moderate Anxiety" 3 "Severe Anxiety"
	label val anxiety anxiety
	tab anxiety
	
	*Generate parenting stress continuous
	gen stress_cont= parenting_time_energy+parenting_worries+not_close+no_affection+parenting_stress+parenting_time_flexibility+parenting_financial_burden+balancing_responsibilities+child_behavior_embarrassment+parenting_overwhelm+limited_choices_control
	label var stress_cont "Parenting Stress Continuous Score"
	
	*Generate dichotomous food insecurity variable
	gen any_food= 1 if food_worries==1 | healthy_food_access==1 | limited_food_choices==1 | meal_skipping==1 | eating_less==1 | food_shortage==1 | hunger_without_eating==1 | whole_day_without_eating==1
	replace any_food=0 if any_food==.
	label var any_food "Experienced Food Insecurity"
	label define any_food 0 "No" 1 "Yes"
	label val any_food any_food
	tab any_food	
	
	*Generate continuous food insecurity variable 
	gen food_insecure= food_worries+healthy_food_access +limited_food_choices +meal_skipping+ eating_less +food_shortage +hunger_without_eating+ whole_day_without_eating
	label var food_insecure "Food Insecurity Continuous"
	
	*Generate dichotomous mental health variables
	*high stress
	gen high_stress=0 if stress_cont<=9
	replace high_stress=1 if stress_cont>=10
	label var high_stress "High Stress"
	label define high_stress 0 "Low Stress" 1 "High Stress"
	label val high_stress high_stress
	tab high_stress	
	
	*high anxiety
	gen high_anxiety=0 
	replace high_anxiety=1 if anxiety>=2
	label var high_anxiety "High Anxiety"
	label define high_anxiety 0 "Low Anxiety" 1 "High Anxiety"
	label val high_anxiety high_anxiety
	tab high_anxiety
	
	*only depression
	gen only_depress=0
	replace only_depress=1 if depress==1 & high_stress==0 & high_anxiety==0
	tab only_depress
	label var only_depress "Only Depression"

	*only anxiety
	gen only_anxiety=0
	replace only_anxiety=1 if depress==0 & high_stress==0 & high_anxiety==1
	tab only_anxiety
	label var only_anxiety "Only Anxiety"

	*only stress
	gen only_stress=0
	replace only_stress=1 if depress==0 & high_stress==1 & high_anxiety==0
	tab only_stress
	label var only_stress "Only Stress"

	*depression and anxiety
	gen depress_anxiety=0
	replace depress_anxiety=1 if depress==1 & high_stress==0 & high_anxiety==1
	label var depress_anxiety "Only Depression and Anxiety"
	tab depress_anxiety

	*depression and stress
	gen depress_stress=0
	replace depress_stress=1 if depress==1 & high_stress==1 & high_anxiety==0
	label var depress_stress "Only Depression and Stress"
	tab depress_stress
	
	*anxiety and stress
	gen anxiety_stress=0
	replace anxiety_stress=1 if depress==0 & high_stress==1 & high_anxiety==1
	label var anxiety_stress "Only Anxiety and Stress"
	tab anxiety_stress

	*anxiety, stress, and depression
	gen anxiety_stress_depress=0
	replace anxiety_stress_depress=1 if depress==1 & high_stress==1 & high_anxiety==1
	label var anxiety_stress_depress "Anxiety, Stress and Depression"
	tab anxiety_stress_depress

	*none
	gen no_SDA=0
	replace no_SDA=1 if depress==0 & high_stress==0 & high_anxiety==0
	label var no_SDA "No Maternal Mental Health Conditions"
	tab no_SDA
	
	*updated refugee status variables
	gen refugee_status=0
	replace refugee_status=1 if refugee_yn_enums==1
	label var refugee_status "Refugee Status"
	label define refugee_status 0 "Non-Refugee" 1 "Refugee"
	label val refugee_status refugee_status
	tab refugee_status	
	

	*clean and generate AIM-ECD variables 
	
	*fix aim ECD data

*listening comprehension
list ID if dal_lc01==99 & dal_lc02==99 & dal_lc03==99 & dal_lc04==99 & dal_lc05==99 & AGE>=36

replace dal_lc01= 1 if dal_lc01==2
replace dal_lc01=0 if dal_lc01==99 & ID!="026e5c36cadf" & ID!="429fae502fb8"
replace dal_lc01=. if dal_lc01==99

replace dal_lc02= 1 if dal_lc02==2
replace dal_lc02=0 if dal_lc02==99 & ID!="026e5c36cadf" & ID!="429fae502fb8"
replace dal_lc02=. if dal_lc02==99

replace dal_lc03= 1 if dal_lc03==2
replace dal_lc03=0 if dal_lc03==99 & ID!="026e5c36cadf" & ID!="429fae502fb8"
replace dal_lc03=. if dal_lc03==99

replace dal_lc04= 1 if dal_lc04==2
replace dal_lc04=0 if dal_lc04==99 & ID!="026e5c36cadf" & ID!="429fae502fb8"
replace dal_lc04=. if dal_lc04==99

replace dal_lc05= 1 if dal_lc05==2
replace dal_lc05=0 if dal_lc05==99 & ID!="026e5c36cadf" & ID!="429fae502fb8"
replace dal_lc05=. if dal_lc05==99

gen lc= dal_lc01+dal_lc02+dal_lc03+dal_lc04+dal_lc05
tab lc

gen lc_pc= lc/5
tab lc_pc

*letter identification
 tabstat dal_li01 dal_li02 dal_li03 dal_li04 dal_li05 dal_li06 dal_li07 dal_li08 dal_li09 dal_li10 dal_li11 dal_li12 dal_li13 dal_li14 dal_li15 dal_li16 dal_li17 dal_li18 dal_li19 dal_li20, stats(mean sd n min max) col(statistics)

replace dal_li02=0 if dal_li02==99
replace dal_li03=0 if dal_li03==99
replace dal_li06=0 if dal_li06==99
replace dal_li07=0 if dal_li07==99
replace dal_li08=0 if dal_li08==99
replace dal_li09=0 if dal_li09==99
replace dal_li10=0 if dal_li10==99
replace dal_li11=0 if dal_li11==99 | (dal_li11==. & AGE>=36)
replace dal_li12=0 if dal_li12==99 | (dal_li12==. & AGE>=36)
replace dal_li13=0 if dal_li13==99 | (dal_li13==. & AGE>=36)
replace dal_li14=0 if dal_li14==99 | (dal_li14==. & AGE>=36)
replace dal_li15=0 if dal_li15==99 | (dal_li15==. & AGE>=36)
replace dal_li16=0 if dal_li16==99 | (dal_li16==. & AGE>=36)
replace dal_li17=0 if dal_li17==99 | (dal_li17==. & AGE>=36)
replace dal_li18=0 if dal_li18==99 | (dal_li18==. & AGE>=36)
replace dal_li19=0 if dal_li19==99 | (dal_li19==. & AGE>=36)
replace dal_li20=0 if dal_li20==99 | (dal_li20==. & AGE>=36)

 tabstat dal_li01 dal_li02 dal_li03 dal_li04 dal_li05 dal_li06 dal_li07 dal_li08 dal_li09 dal_li10 dal_li11 dal_li12 dal_li13 dal_li14 dal_li15 dal_li16 dal_li17 dal_li18 dal_li19 dal_li20, stats(mean sd n min max) col(statistics)
 
 gen li= dal_li01+dal_li02+dal_li03+dal_li04+dal_li05+dal_li06+dal_li07+dal_li08+dal_li09+dal_li10+dal_li11+dal_li12+dal_li13+dal_li14+dal_li15+dal_li16+dal_li17+dal_li18+dal_li19+dal_li20
 tab li

gen li_pc= li/20
tab li_pc
 
*initial sound discrimination *MISSING FOR 67 KIDS* *only 638 observations*
tab dal_sd01
tab dal_sd01, nolab

replace dal_sd01=0 if dal_sd01==2 | dal_sd01==99
replace dal_sd02=0 if dal_sd02==2 | dal_sd02==99
replace dal_sd03=0 if dal_sd03==2 | dal_sd03==99
 
 tabstat dal_sd01 dal_sd02 dal_sd03, stats(mean sd n min max) col(statistics)
 
 gen sd= dal_sd01+dal_sd02+dal_sd03
 tab sd
 
 gen sd_pc= sd/3
 tab sd_pc
 
*writing level
 tab dal_nw01
 gen nw_pc= dal_nw01/4
 
 tab nw_pc
 
 *receptive spacial vocabulary
 tabstat dan_sv01 dan_sv02 dan_sv03 dan_sv04, stats(mean sd n min max) col(statistics)
 tab dan_sv01
 tab dan_sv01, nolab
 
replace dan_sv01=0 if dan_sv01==2 | dan_sv01==99
replace dan_sv02=0 if dan_sv02==2 | dan_sv02==99
replace dan_sv03=0 if dan_sv03==2 | dan_sv03==99
replace dan_sv04=0 if dan_sv04==2 | dan_sv04==99 

 tabstat dan_sv01 dan_sv02 dan_sv03 dan_sv04, stats(mean sd n min max) col(statistics) 
 
 gen sv= dan_sv01+dan_sv02+dan_sv03+dan_sv04
 tab sv
 
 gen sv_pc= sv/4
 tab sv_pc
 
 *producing a set
 tabstat dan_ps01 dan_ps02 dan_ps03 dan_ps04, stats(mean sd n min max) col(statistics)
 tab dan_ps01
 tab dan_ps01, nolab
 
replace dan_ps01=0 if dan_ps01==2 | dan_ps01==99
replace dan_ps02=0 if dan_ps02==2 | dan_ps02==99
replace dan_ps03=0 if dan_ps03==2 | dan_ps03==99 | (dan_ps03==. & AGE>=36)
replace dan_ps04=0 if dan_ps04==2 | dan_ps04==99 | (dan_ps04==. & AGE>=36) 

 tabstat dan_ps01 dan_ps02 dan_ps03 dan_ps04, stats(mean sd n min max) col(statistics) 
 
 gen ps= dan_ps01+dan_ps02+dan_ps03+dan_ps04
 tab ps
 
 gen ps_pc= ps/4
 tab ps_pc 
 
 *addition
 tabstat dan_sa01 dan_sa02 dan_sa03, stats(mean sd n min max) col(statistics)
 tab dan_sa01
 tab dan_sa01, nolab
 
 list ID if dan_sa01==99 & dan_sa02==99 & dan_sa03==99 & AGE>=36

replace dan_sa01=0 if (dan_sa01==2 | dan_sa01==99) & ID!="e79e989b2776"
replace dan_sa02=0 if (dan_sa02==2 | dan_sa02==99) & ID!="e79e989b2776"
replace dan_sa03=0 if (dan_sa03==2 | dan_sa03==99) & ID!="e79e989b2776"

replace dan_sa01=. if dan_sa01==99 & ID=="e79e989b2776"
replace dan_sa02=. if dan_sa02==99 & ID=="e79e989b2776"
replace dan_sa03=. if dan_sa03==99 & ID=="e79e989b2776"

 tabstat dan_sa01 dan_sa02 dan_sa03, stats(mean sd n min max) col(statistics) 
 
 gen ad= dan_sa01+dan_sa02+dan_sa03
 tab ad
 
 gen ad_pc= ad/3
 tab ad_pc 
 
 *number identification
  tabstat dan_ni01 dan_ni02 dan_ni03 dan_ni04 dan_ni05 dan_ni06 dan_ni07 dan_ni08 dan_ni09 dan_ni10 dan_ni11 dan_ni12 dan_ni13 dan_ni14 dan_ni15 dan_ni16 dan_ni17 dan_ni18 dan_ni19 dan_ni20, stats(mean sd n min max) col(statistics)
 tab dan_ni01
 tab dan_ni01, nolab
 
 tab dan_ni05
 tab dan_ni05, nolab
 
 replace dan_ni01=1 if dan_ni01==2
 replace dan_ni02=1 if dan_ni02==2
 replace dan_ni03=1 if dan_ni03==2
 replace dan_ni04=1 if dan_ni04==2
 
 replace dan_ni05=1 if dan_ni05==2
 replace dan_ni05=0 if dan_ni05==99
 
 replace dan_ni06=1 if dan_ni06==2
 replace dan_ni06=0 if dan_ni06==99
 
 replace dan_ni07=1 if dan_ni07==2
 replace dan_ni07=0 if dan_ni07==99
 
 replace dan_ni08=1 if dan_ni08==2
 replace dan_ni08=0 if dan_ni08==99 

 replace dan_ni09=1 if dan_ni09==2
 replace dan_ni09=0 if dan_ni09==99
 
 replace dan_ni10=1 if dan_ni10==2
 replace dan_ni10=0 if dan_ni10==99 
 
 replace dan_ni11=1 if dan_ni11==2
 replace dan_ni11=0 if dan_ni11==99 | (dan_ni11==. & AGE>=36)
 
 replace dan_ni12=1 if dan_ni12==2
 replace dan_ni12=0 if dan_ni12==99 | (dan_ni12==. & AGE>=36)
 
 replace dan_ni13=1 if dan_ni13==2
 replace dan_ni13=0 if dan_ni13==99 | (dan_ni13==. & AGE>=36) 
 
 replace dan_ni14=1 if dan_ni14==2
 replace dan_ni14=0 if dan_ni14==99 | (dan_ni14==. & AGE>=36) 
 
 replace dan_ni15=1 if dan_ni15==2
 replace dan_ni15=0 if dan_ni15==99 | (dan_ni15==. & AGE>=36) 
 
 replace dan_ni16=1 if dan_ni16==2
 replace dan_ni16=0 if dan_ni16==99 | (dan_ni16==. & AGE>=36) 
 
 replace dan_ni17=1 if dan_ni17==2
 replace dan_ni17=0 if dan_ni17==99 | (dan_ni17==. & AGE>=36) 
 
 replace dan_ni18=1 if dan_ni18==2
 replace dan_ni18=0 if dan_ni18==99 | (dan_ni18==. & AGE>=36)
 
 replace dan_ni19=1 if dan_ni19==2
 replace dan_ni19=0 if dan_ni19==99 | (dan_ni19==. & AGE>=36) 
 
 replace dan_ni20=1 if dan_ni20==2
 replace dan_ni20=0 if dan_ni20==99 | (dan_ni20==. & AGE>=36)
 
 tabstat dan_ni01 dan_ni02 dan_ni03 dan_ni04 dan_ni05 dan_ni06 dan_ni07 dan_ni08 dan_ni09 dan_ni10 dan_ni11 dan_ni12 dan_ni13 dan_ni14 dan_ni15 dan_ni16 dan_ni17 dan_ni18 dan_ni19 dan_ni20, stats(mean sd n min max) col(statistics) 
 
 gen ni= dan_ni01+dan_ni02+dan_ni03+dan_ni04+dan_ni05+dan_ni06+dan_ni07+dan_ni08+dan_ni09+dan_ni10+dan_ni11+dan_ni12+dan_ni13+dan_ni14+dan_ni15+dan_ni16+dan_ni17+dan_ni18+dan_ni19+dan_ni20
 tab ni
 
 gen ni_pc= ni/20
 tab ni_pc 
 
 *number comparison
 tabstat dan_nc01 dan_nc02 dan_nc03, stats(mean sd n min max) col(statistics)
 tab dan_nc01
 tab dan_nc01, nolab
 
 list ID if dan_nc01==99 & dan_nc02==99 & dan_nc03==99 & AGE>=36
 
 replace dan_nc01=1 if dan_nc01==2
 replace dan_nc01=0 if dan_nc01==99 & ID!="429fae502fb8" & ID!="6ed41a03427e" & ID!="d09845da07e3"
 
 replace dan_nc02=1 if dan_nc02==2
 replace dan_nc02=0 if dan_nc02==99 & ID!="429fae502fb8" & ID!="6ed41a03427e" & ID!="d09845da07e3"
 
 replace dan_nc03=1 if dan_nc03==2
 replace dan_nc03=0 if dan_nc03==99 & ID!="429fae502fb8" & ID!="6ed41a03427e" & ID!="d09845da07e3"
 
replace dan_nc01=. if dan_nc01==99 & (ID=="429fae502fb8" | ID=="6ed41a03427e" | ID=="d09845da07e3")
replace dan_nc02=. if dan_nc02==99 & (ID=="429fae502fb8" | ID=="6ed41a03427e" | ID=="d09845da07e3")
replace dan_nc03=. if dan_nc03==99 & (ID=="429fae502fb8" | ID=="6ed41a03427e" | ID=="d09845da07e3")

 tabstat dan_nc01 dan_nc02 dan_nc03, stats(mean sd n min max) col(statistics) 
 
 gen nc= dan_nc01+dan_nc02+dan_nc03
 tab nc
 
 gen nc_pc= nc/3
 tab nc_pc 
 
 *shape identification
 tabstat dan_si_01 dan_si_02 dan_si_03 dan_si_04 shape_10e, stats(mean sd n min max) col(statistics)
 tab dan_si_01
 tab dan_si_01, nolab
 
 list ID if dan_si_01==99 & dan_si_02==99 & dan_si_03==99 & dan_si_04==99 & shape_10e==99 & AGE>=36
 
 replace dan_si_01=0 if dan_si_01==2
 replace dan_si_01=0 if dan_si_01==99

 replace dan_si_02=0 if dan_si_02==2
 replace dan_si_02=0 if dan_si_02==99 
 
 replace dan_si_03=0 if dan_si_03==2
 replace dan_si_03=0 if dan_si_03==99 
 
 replace dan_si_04=0 if dan_si_04==2
 replace dan_si_04=0 if dan_si_04==99
 
 replace shape_10e=0 if shape_10e==2
 replace shape_10e=0 if shape_10e==99
 
 tabstat dan_si_01 dan_si_02 dan_si_03 dan_si_04 shape_10e, stats(mean sd n min max) col(statistics)
 
 gen shape= dan_si_01+dan_si_02+dan_si_03+dan_si_04+shape_10e
 tab shape
 
 gen shape_pc= shape/5
 tab shape_pc  
 
 *head toes knees shoulders
 tabstat dae_ht_cont1 dae_ht01 dae_ht02 dae_ht03 dae_ht04 dae_ht05 shoulder_understanding dae_ht06 dae_ht07 dae_ht08 dae_ht09 dae_ht10 dae_ht11 dae_ht12 dae_ht13 dae_ht14 dae_ht15, stats(mean sd n min max) col(statistics)
 tab dae_ht_cont1
 tab dae_ht_cont1, nolab
 
 tab dae_ht01
 tab dae_ht01, nolab
  
 replace dae_ht_cont1=0 if dae_ht_cont1==88

 replace dae_ht01=0 if dae_ht01==3 | dae_ht01==99
 replace dae_ht01=3 if dae_ht01==1
 replace dae_ht01=1 if dae_ht01==2
 replace dae_ht01=2 if dae_ht01==3
 replace dae_ht01=0 if (dae_ht01==. & AGE>=36)
 
  replace dae_ht02=0 if dae_ht02==3 | dae_ht02==99
 replace dae_ht02=3 if dae_ht02==1
 replace dae_ht02=1 if dae_ht02==2
 replace dae_ht02=2 if dae_ht02==3
 replace dae_ht02=0 if (dae_ht02==. & AGE>=36)
 
  replace dae_ht03=0 if dae_ht03==3 | dae_ht03==99
 replace dae_ht03=3 if dae_ht03==1
 replace dae_ht03=1 if dae_ht03==2
 replace dae_ht03=2 if dae_ht03==3
 replace dae_ht03=0 if (dae_ht03==. & AGE>=36)
 
  replace dae_ht04=0 if dae_ht04==3 | dae_ht04==99
 replace dae_ht04=3 if dae_ht04==1
 replace dae_ht04=1 if dae_ht04==2
 replace dae_ht04=2 if dae_ht04==3
 replace dae_ht04=0 if (dae_ht04==. & AGE>=36)
 
  replace dae_ht05=0 if dae_ht05==3 | dae_ht05==99
 replace dae_ht05=3 if dae_ht05==1
 replace dae_ht05=1 if dae_ht05==2
 replace dae_ht05=2 if dae_ht05==3
 replace dae_ht05=0 if (dae_ht05==. & AGE>=36)
 
 tab shoulder_understanding
 tab shoulder_understanding, nolab
 
  replace dae_ht06=0 if dae_ht06==3 | dae_ht06==99
 replace dae_ht06=3 if dae_ht06==1
 replace dae_ht06=1 if dae_ht06==2
 replace dae_ht06=2 if dae_ht06==3
 replace dae_ht06=0 if (dae_ht06==. & AGE>=36)
 
  replace dae_ht07=0 if dae_ht07==3 | dae_ht07==99
 replace dae_ht07=3 if dae_ht07==1
 replace dae_ht07=1 if dae_ht07==2
 replace dae_ht07=2 if dae_ht07==3
 replace dae_ht07=0 if (dae_ht07==. & AGE>=36)
 
  replace dae_ht08=0 if dae_ht08==3 | dae_ht08==99
 replace dae_ht08=3 if dae_ht08==1
 replace dae_ht08=1 if dae_ht08==2
 replace dae_ht08=2 if dae_ht08==3
 replace dae_ht08=0 if (dae_ht08==. & AGE>=36)
 
  replace dae_ht09=0 if dae_ht09==3 | dae_ht09==99
 replace dae_ht09=3 if dae_ht09==1
 replace dae_ht09=1 if dae_ht09==2
 replace dae_ht09=2 if dae_ht09==3
 replace dae_ht09=0 if (dae_ht09==. & AGE>=36)
 
  replace dae_ht10=0 if dae_ht10==3 | dae_ht10==99
 replace dae_ht10=3 if dae_ht10==1
 replace dae_ht10=1 if dae_ht10==2
 replace dae_ht10=2 if dae_ht10==3
 replace dae_ht10=0 if (dae_ht10==. & AGE>=36)
 
  replace dae_ht11=0 if dae_ht11==3 | dae_ht11==99
 replace dae_ht11=3 if dae_ht11==1
 replace dae_ht11=1 if dae_ht11==2
 replace dae_ht11=2 if dae_ht11==3
 replace dae_ht11=0 if (dae_ht11==. & AGE>=36)
 
  replace dae_ht12=0 if dae_ht12==3 | dae_ht12==99
 replace dae_ht12=3 if dae_ht12==1
 replace dae_ht12=1 if dae_ht12==2
 replace dae_ht12=2 if dae_ht12==3
 replace dae_ht12=0 if (dae_ht12==. & AGE>=36)
 
  replace dae_ht13=0 if dae_ht13==3 | dae_ht13==99
 replace dae_ht13=3 if dae_ht13==1
 replace dae_ht13=1 if dae_ht13==2
 replace dae_ht13=2 if dae_ht13==3
 replace dae_ht13=0 if (dae_ht13==. & AGE>=36)
 
  replace dae_ht14=0 if dae_ht14==3 | dae_ht14==99
 replace dae_ht14=3 if dae_ht14==1
 replace dae_ht14=1 if dae_ht14==2
 replace dae_ht14=2 if dae_ht14==3
 replace dae_ht14=0 if (dae_ht14==. & AGE>=36)
 
  replace dae_ht15=0 if dae_ht15==3 | dae_ht15==99
 replace dae_ht15=3 if dae_ht15==1
 replace dae_ht15=1 if dae_ht15==2
 replace dae_ht15=2 if dae_ht15==3
 replace dae_ht15=0 if (dae_ht15==. & AGE>=36)
 
 replace shoulder_understanding=0 if shoulder_understanding==. & AGE>=36
 
 tab dae_ht06
 tab dae_ht06, nolab

  tabstat dae_ht_cont1 dae_ht01 dae_ht02 dae_ht03 dae_ht04 dae_ht05 shoulder_understanding dae_ht06 dae_ht07 dae_ht08 dae_ht09 dae_ht10 dae_ht11 dae_ht12 dae_ht13 dae_ht14 dae_ht15, stats(mean sd n min max) col(statistics)
  
 gen headshoulders= dae_ht01+dae_ht02+dae_ht03+dae_ht04+dae_ht05+dae_ht06+dae_ht07+dae_ht08+dae_ht09+dae_ht10+dae_ht11+dae_ht12+dae_ht13+dae_ht14+dae_ht15
 tab headshoulders
 
 gen headshoulders_pc= headshoulders/30
 tab headshoulders_pc  
  
 *forward digit span
 tabstat dae_fs01 dae_fs02 dae_fs03 dae_fs04, stats(mean sd n min max) col(statistics)
 tab dae_fs01
 tab dae_fs01, nolab
 
 list ID if dae_fs01==99 & dae_fs02==99 & dae_fs03==99 & dae_fs04==99 & AGE>=36
 
 replace dae_fs01=1 if dae_fs01==2
 replace dae_fs01=0 if dae_fs01==99 & ID!="429fae502fb8" & ID!="e79e989b2776"

 replace dae_fs02=1 if dae_fs02==2
 replace dae_fs02=0 if dae_fs02==99 & ID!="429fae502fb8" & ID!="e79e989b2776"
 
 replace dae_fs03=1 if dae_fs03==2
 replace dae_fs03=0 if dae_fs03==99 & ID!="429fae502fb8" & ID!="e79e989b2776" 

 replace dae_fs04=1 if dae_fs04==2
 replace dae_fs04=0 if dae_fs04==99 & ID!="429fae502fb8" & ID!="e79e989b2776"
 
 replace dae_fs01=. if ID=="429fae502fb8" | ID=="e79e989b2776"
 replace dae_fs02=. if ID=="429fae502fb8" | ID=="e79e989b2776"
 replace dae_fs03=. if ID=="429fae502fb8" | ID=="e79e989b2776"
 replace dae_fs04=. if ID=="429fae502fb8" | ID=="e79e989b2776"

 tabstat dae_fs01 dae_fs02 dae_fs03 dae_fs04, stats(mean sd n min max) col(statistics)
 
 gen fds= dae_fs01+dae_fs02+dae_fs03+dae_fs04
 tab fds
 
 gen fds_pc= fds/4
 tab fds_pc  
 
 *backward digit span
 tabstat dae_bs01 dae_bs02 dae_bs03 dae_bs04, stats(mean sd n min max) col(statistics)
 tab dae_bs01
 tab dae_bs01, nolab
 
 list ID if dae_bs01==99 & dae_bs02==99 & dae_bs03==99 & dae_bs04==99 & AGE>=36
 
 replace dae_bs01=1 if dae_bs01==2
 replace dae_bs01=. if dae_bs01==99

 replace dae_bs02=1 if dae_bs02==2
 replace dae_bs02=. if dae_bs01==.
 replace dae_bs02=0 if dae_bs02==99
 
 replace dae_bs03=1 if dae_bs03==2
 replace dae_bs03=. if dae_bs01==.
 replace dae_bs03=0 if dae_bs03==99

 replace dae_bs04=1 if dae_bs04==2
 replace dae_bs04=. if dae_bs01==.
 replace dae_bs04=0 if dae_bs04==99

 tabstat dae_bs01 dae_bs02 dae_bs03 dae_bs04, stats(mean sd n min max) col(statistics)
 
 gen bds= dae_bs01+dae_bs02+dae_bs03+dae_bs04
 tab bds
 
 gen bds_pc= bds/4
 tab bds_pc  

 *perspective taking/empathy
   tabstat das_pt01 das_pt02 das_pt03, stats(mean sd n min max) col(statistics)
 tab das_pt01
 tab das_pt01, nolab
  
 replace das_pt01=0 if das_pt01==99

 replace das_pt02=0 if das_pt02==99 | (das_pt02==. & AGE>=36)
 
 replace das_pt03=0 if das_pt03==99 | (das_pt03==. & AGE>=36)

   tabstat das_pt01 das_pt02 das_pt03, stats(mean sd n min max) col(statistics)
 
 gen empathy= das_pt01+das_pt02+das_pt03
 tab empathy
 
 gen empathy_pc= empathy/3
 tab empathy_pc  
 
  *create domain sum scores
 gen early_literacy= (lc_pc+li_pc+sd_pc+nw_pc)/4
 tab early_literacy
 
 gen early_numeracy= (sv_pc+ps_pc+ad_pc+ni_pc+nc_pc+shape_pc)/6
 tab early_numeracy
 
 gen executive_functioning= (headshoulders_pc+fds_pc+bds_pc)/3
 tab executive_functioning
 
 gen social_emotional= empathy_pc
 tab social_emotional
 
 gen AIMECD_DA= (early_literacy+early_numeracy+executive_functioning+social_emotional)/4
 tab AIMECD_DA
  
*save dataset
save "$data/KP survey_clean.dta", replace
