********************************************************************************
*																			   *
*           Maternal Mental Health and its influence on Children's             *
*           Early Development: Evidence from Khyber Pakhtunkhwa, Pakistan	   *
*													                           *
*																			   *
*           Stata .do file 1b: Creat asset index			  				   *
*																			   *
********************************************************************************

************
* Creat asset index
************


*-------------------------------------------------------------------------------
*STEP 1: IMPORT CLEAN DATA FILE
*-------------------------------------------------------------------------------
clear all

use "$data/KP survey_clean.dta", clear

*-------------------------------------------------------------------------------
*STEP 2: RECODING
*-------------------------------------------------------------------------------
*Main construction material used for walls (ls02se01)
gen w1 = .
replace w1 = 1 if walls_material == 1
replace w1 = 0 if walls_material != 1

label variable w1 "Main construction material used for house walls"
label define w1 1 "Burned Bricks/Blocks" 0 "Other"
label value w1 w1

gen w2 = .
replace w2 = 1 if walls_material == 2
replace w2 = 0 if walls_material != 2

label variable w2 "Main construction material used for house walls"
label define w2 1 "Raw Bricks/Mud" 0 "Other"
label value w2 w2

gen w3 = .
replace w3 = 1 if walls_material == 3
replace w3 = 0 if walls_material != 3

label variable w3 "Main construction material used for house walls"
label define w3 1 "Wood/Bamboo" 0 "Other"
label value w3 w3

gen w4 = .
replace w4 = 1 if walls_material == 4
replace w4 = 0 if walls_material != 4

label variable w4 "Main construction material used for house walls"
label define w4 1 "Stone" 0 "Other"
label value w4 w4

summarize walls_material w1 w2 w3 w4

**Main construction material used for roof (ls02se03)	
gen r1 = .
replace r1 = 1 if roof_material == 1
replace r1 = 0 if roof_material != 1

label variable r1 "Main construction material used for house roof"
label define r1 1 "Reinforced Cement Concrete/Reinforced B" 0 "Other"
label value r1 r1

gen r2 = .
replace r2 = 1 if roof_material == 2
replace r2 = 0 if roof_material != 2

label variable r2 "Main construction material used for house roof"
label define r2 1 "Wood/Bamboo" 0 "Other"
label value r2 r2

gen r3 = .
replace r3 = 1 if roof_material == 3
replace r3 = 0 if roof_material != 3

label variable r3 "Main construction material used for house roof"
label define r3 1 "Iron/Cement Sheets" 0 "Other"
label value r3 r3

gen r4 = .
replace r4 = 1 if roof_material == 4
replace r4 = 0 if roof_material != 4

label variable r4 "Main construction material used for house roof"
label define r4 1 "Girder /T-Iron" 0 "Other"
label value r4 r4

summarize roof_material r1 r2 r3 r4

*Ownership status of your house (ls02se04)
gen h1 = .
replace h1 = 1 if house_status == 1
replace h1 = 0 if house_status != 1

label variable h1 "Ownership status of your house"
label define h1 1 "Owner Occupied" 0 "Other"
label value h1 h1

gen h2 = .
replace h2 = 1 if house_status == 2
replace h2 = 0 if house_status != 2

label variable h2 "Ownership status of your house"
label define h2 1 "On Rent" 0 "Other"
label value h2 h2

gen h3 = .
replace h3 = 1 if house_status == 3
replace h3 = 0 if house_status != 3

label variable h3 "Ownership status of your house"
label define h3 1 "Subsidized Rent" 0 "Other"
label value h3 h3

gen h4 = .
replace h4 = 1 if house_status == 4
replace h4 = 0 if house_status != 4 

label variable h4 "Ownership status of your house"
label define h4 1 "Rent Free" 0 "other"
label value h4 h4

summarize house_status h1 h2 h3 h4 

*Type of the fuel mainly used for cooking (ls02se13)
gen fuel1 = .
replace fuel1 = 1 if fuel == 2 | fuel == 3
replace fuel1 = 0 if fuel != 2 & fuel != 3

label variable fuel1 "Type of the fuel mainly used for cooking"
label define fuel1 1 "Gas/Kerosene" 0 "Other"
label value fuel1 fuel1 //combine gas & kerosene//

gen fuel2 = .
replace fuel2 = 1 if fuel == 1 | fuel >= 4
replace fuel2 = 0 if fuel != 1 & fuel != 4 & fuel != 5 & fuel != 6 & fuel != 7

label variable fuel2 "Type of the fuel mainly used for cooking"
label define fuel2 1 "Firewood" 0 "Other" //combine firewood & charcoal & kerosene oil & dung cake & electricity & crp residue//
label value fuel2 fuel2

summarize fuel fuel1 fuel2 

*Main source of drinking water (ls02se07)
gen dw1 = .
replace dw1 = 1 if drinking_water >= 1 & drinking_water<=7
replace dw1 = 0 if drinking_water != 1 & drinking_water != 2 & drinking_water != 3 & drinking_water != 4 & drinking_water != 5 & drinking_water != 6 & drinking_water != 7

label variable dw1 "Main source of drinking water"
label define dw1 1 "Private, Reliable Source of Drinking Water" 0 "Other" //combine these three options as having private sources of drinking water//
label value dw1 dw1

gen dw2 = .
replace dw2 = 1 if drinking_water == 8 | drinking_water == 9 | drinking_water == 10 | drinking_water == 11 | drinking_water == 13 | drinking_water== 18
replace dw2 = 0 if drinking_water != 8 & drinking_water != 9 & drinking_water != 10 & drinking_water != 11 & drinking_water != 13 & drinking_water != 18

label variable dw2 "Main source of drinking water"
label define dw2 1 "Shared, Reliable Source of Drinking Water" 0 "Other" //combine these four options as having public sources of drinking water// 
label value dw2 dw2

gen dw3 = .
replace dw3 = 1 if drinking_water == 12 | drinking_water == 14 | drinking_water == 15 | drinking_water == 16 | drinking_water == 17 
replace dw3 = 0 if drinking_water != 12 & drinking_water != 14 & drinking_water != 15 & drinking_water != 16 & drinking_water != 17 
label variable dw3 "Main source of drinking water"
label define dw3 1 "Shared, Unreliable Source of Drinking Water" 0 "Other" //combine these four options as having public sources of unreliable drinking water//
label value dw3 dw3

summarize drinking_water dw1 dw2 dw3 

*Type of toilet (ls02se09)
gen tf1 = .
replace tf1 = 1 if toilet >= 2 & toilet<=5
replace tf1 = 0 if toilet != 2 & toilet != 3 & toilet != 4 & toilet != 5

label variable tf1 "Type of toilet"
label define tf1 1 "Latrine with flush system" 0 "Other"
label value tf1 tf1

gen tf2 = .
replace tf2 = 1 if toilet >= 6
replace tf2 = 0 if toilet != 6

label variable tf2 "Type of toilet"
label define tf2 1 "Latrine without flush system" 0 "Other"
label value tf2 tf2

gen tf3 = .
replace tf3 = 1 if toilet == 1
replace tf3 = 0 if toilet != 1

label variable tf3 "Type of toilet"
label define tf3 1 "No toilet" 0 "Other", replace
label value tf3 tf3

summarize toilet tf1 tf2 tf3 /// more than 90% with latrine with flush system, exclude from PCA

*gas connection
gen g1 = .
replace g1 = 1 if gas == 1
replace g1 = 0 if gas != 1

label variable g1 "Gas connection"
label define g1 1 "Gas connection in home" 0 "Other"
label value g1 g1

gen g2 = .
replace g2 = 1 if gas == 2
replace g2 = 0 if gas != 2

label variable g2 "Gas connection"
label define g2 1 "Gas connection with extension" 0 "Other"
label value g2 g2

gen g3 = .
replace g3 = 1 if gas == 3
replace g3 = 0 if gas != 3

label variable g3 "Gas connection"
label define g3 1 "No gas connection" 0 "Other", replace
label value g3 g3

summarize gas g1 g2 g3 

*exclude landline, 98% with no landline
*exclude camels, no one has any; air condiitoner, fan 

*-------------------------------------------------------------------------------
*STEP 3: Copying all the assets and number of rooms of household
*-------------------------------------------------------------------------------
replace livestock=0 if livestock==2
tab livestock

replace internet=0 if internet==88
replace bicycle=0 if bicycle==88
replace cart=0 if cart==88

replace buffalo=0 if buffalo==.
replace cow=0 if cow==.
replace goat=0 if goat==.

gen assets1 = livestock
gen assets2 = buffalo
gen assets3 = cow 
gen assets4 = goat 
gen assets5 = horse 
gen assets6 = agriland_owner 
gen assets7 = heater 
gen assets8 = washing_machene 
gen assets9 = geyser
gen assets10 = air_cooler
gen assets11 = air_conditioner 
gen assets12 = fan 
gen assets13 = cooking_range 
gen assets14 = stove 
gen assets15 = tv 
gen assets16 = refrigerator 
gen assets17 = freezer
gen assets18 = sewing
gen assets19 = computer 
gen assets20 = motorcyle
gen assets21 = car
gen assets22 = cellphone
gen assets23 = watch
gen assets24 = bicycle
gen assets25= internet
gen pprooms = hhmem_count/rooms

replace assets5=0 if assets5==.

label variable assets1 "livestock"	
label variable assets2 "buffalo"	
label variable assets3 "cow"	
label variable assets4 "goats"	
label variable assets5 "horse"	
label variable assets6 "own agricultural land"	
label variable assets7 "heater"	
label variable assets8 "washing machine"	
label variable assets9 "geyser"	
label variable assets10 "air cooler"	
label variable assets11 "air conditioner"	
label variable assets12 "fan"	
label variable assets13 "cooking range"	
label variable assets14 "stove"	
label variable assets15 "tv"	
label variable assets16 "fridge"	
label variable assets17 "freezer"	
label variable assets18 "sewing machine"
label variable assets19 "computer"	
label variable assets20 "motor cycle"	
label variable assets21 "car"	
label variable assets22 "cellphone"	
label variable assets23 "watch"
label variable assets24 "bike"	
label variable assets25 "internet"	
label variable pprooms "Persons per room"

sum assets1 - pprooms 

tabstat w1 w2 w3 w4 r1 r2 r3 r4 h1 h2 h3 h4 fuel1 fuel2 dw1 dw2 dw3 tf1 tf2 tf3 g1 g2 g3 assets1 assets2 assets3 assets4 assets5 assets6 assets7 assets8 assets9 assets10 assets11 assets12 assets13 assets14 assets15 assets16 assets17 assets18 assets19 assets20 assets21 assets22 assets23 assets24 assets25 pproom, s(min max mean median sd count)

*-------------------------------------------------------------------------------
*STEP 4:  Syntax for the wealth scores and quintiles
*-------------------------------------------------------------------------------
factor w1 w2 w3 w4 r1 r2 r3 r4 h1 h2 h3 h4 fuel1 fuel2 dw1 dw2 dw3 tf1 tf2 tf3 g1 g2 g3 assets1 assets2 assets3 assets4 assets5 assets6 assets7 assets8 assets9 assets10 assets11 assets12 assets13 assets14 assets15 assets16 assets17 assets18 assets19 assets20 assets21 assets22 assets23 assets24 assets25 pprooms, pcf //factor analysis, using the method of principal-component factor, 15.51% variance explained//

predict score3

factor w1 w2 w3 w4 r1 r2 r3 r4 h1 h2 h3 h4 fuel1 fuel2 dw1 dw2 dw3 g1 g2 g3 assets1 assets3 assets4 assets6 assets7 assets8 assets9 assets10 assets14 assets15 assets16 assets18 assets20 assets23 assets24 assets25 pprooms, pcf // 18.75% of variance explained

predict score2

gen wealthm = score2

tabstat wealthm, s(min max mean median sd count)

xtile asset_quintile_update = wealthm, n(5) //divide the wealth score into qunintiles

label variable wealthm "Asset Score (continuous)"
label variable asset_quintile_update "Asset Index (quintiles)"
label define asset_quintile_update 1 "Poorest" 2 "Second" 3 "Third" 4 "Fourth" 5 "Richest"

*SAVE DATASET WITH UPDATES*

*save dataset
save "$data/KP survey_clean.dta", replace
