********************************************************************************
*																			   *
*           Maternal Mental Health and its influence on Children's             *
*           Early Development: Evidence from Khyber Pakhtunkhwa, Pakistan	   *
*													                           *
*																			   *
*           Stata .do file 2: Analysis presented in tables and figures         *
*																			   *
********************************************************************************

	
	*IMPORT CLEANED DATA*
	use "$data/KP survey_clean.dta", clear
		
*descriptive table one
*----------------------------------------------
	
	*set weights
	svyset [pweight=hh_weights]
	
	*child age
	svy linearized: tab agegroup, missing
	tab agegroup, missing
	
	*child gender
	svy linearized: tab fetch_child_gender, missing
	tab fetch_child_gender, missing
	
	*location
	svy linearized: tab rural, missing
	tab rural, missing
	
	*birth registration
	svy linearized: tab doc_dob_1, missing
	tab doc_dob_1, missing
	
	svy linearized: tab doc_dob_3, missing
	tab doc_dob_3, missing
	
	svy linearized: tab doc_dob_2, missing
	tab doc_dob_2, missing
	
	*refugee status
	svy linearized: tab refugee_yn_enums, missing
	tab refugee_yn_enums, missing
	
	*maternal education
	svy linearized: tab maternal_ed_cat1, missing
	tab maternal_ed_cat1, missing
	
	*average child age
	svy linearized: mean AGE
	summ AGE, detail
	
	*average household size
	svy linearized: mean hhmem_count
	summ hhmem_count, detail
	
	*caregiver age
	svy linearized: mean maternal_age
	summ maternal_age, detail
	
	*hh head age
	svy linearized: mean hh_age
	summ hh_age, detail

	*new survey weights for 3+ children
	svyset [pweight=child_weights]
	
	*enrollment in ece
	svy linearized: tab attend_ece
	tab attend_ece
	
	*current class
	svy linearized: tab current_class_final
	tab current_class_final

	*school type
	svy linearized: tab sch_type_update
	tab sch_type_update	
	
	*frequency of ece attendance (days/week)
	svy linearized: tab daysperweek
	tab daysperweek	
	
	*frequency of ece attendance (hours/day)
	svy linearized: tab hoursperday
	tab hoursperday	
	
	
*figure one- sample distribution compared to global distribution (credi)
*----------------------------------------------

twoway histogram Z_OVERALL, start(-6) width(0.2) || function normalden(x, 0,1) , range(-4 4) legend(order(2 "Reference Population")) ytitle(Density)

*figure two- sample distribution compared to global distribution (credi) by primary ed
*----------------------------------------------

twoway hist Z_OVERALL if primary_ed==0, start(-6) width(0.2) || function normalden(x, 0,1) , range(-4 4) legend(order(2 "Reference Population")) ytitle(Density) 

*figure three- sample distribution compared to global distribution (credi) by refugee status
*----------------------------------------------

twoway hist Z_OVERALL if refugee_yn_enums==1, start(-6) width(0.2) || function normalden(x, 0,1) , range(-4 4) legend(order(2 "Reference Population")) ytitle(Density) 

*figure four- sample distribution compared to global distribution (credi) by urban/rural area
*----------------------------------------------

twoway hist Z_OVERALL if rural==1, start(-6) width(0.2) || function normalden(x, 0,1) , range(-4 4) legend(order(2 "Reference Population")) ytitle(Density) 

*figure five- sample distribution compared to global distribution (AIM-ECD) 
*----------------------------------------------
histogram AIMECD_DA, frequency normal ytitle(Density) xtitle(AIM-ECD Direct Assessment Percent Correct)


*table two- prevalence of stressors
*----------------------------------------------

	*set weights
	svyset [pweight=hh_weights]

	*food insecurity
	svy linearized: tab food_worries, missing
	tab food_worries, missing
	
	svy linearized: tab healthy_food_access, missing
	tab healthy_food_access, missing
	
	svy linearized: tab limited_food_choices, missing
	tab limited_food_choices, missing
	
	svy linearized: tab meal_skipping, missing
	tab meal_skipping, missing

	svy linearized: tab eating_less, missing
	tab eating_less, missing

	svy linearized: tab food_shortage, missing
	tab food_shortage, missing

	svy linearized: tab hunger_without_eating, missing
	tab hunger_without_eating, missing

	svy linearized: tab whole_day_without_eating, missing 
	tab whole_day_without_eating, missing 
	
	*flood exposure 
	svy linearized: tab flood_impact_gen, missing
	tab flood_impact_gen, missing	
	
	svy linearized: tab flood_2023_impact, missing
	tab flood_2023_impact, missing	
	
	svy linearized: tab flood_2022_impact, missing
	tab flood_2022_impact, missing	

	*type of 2023 flood impact 
	svy linearized: tab floods_2023_1 if floods_2023_8==0, missing
	tab floods_2023_1 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_1b if floods_2023_8==0, missing
	tab floods_2023_1b if floods_2023_8==0, missing

	svy linearized: tab floods_2023_2 if floods_2023_8==0, missing
	tab floods_2023_2 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_3 if floods_2023_8==0, missing
	tab floods_2023_3 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_4 if floods_2023_8==0, missing
	tab floods_2023_4 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_5 if floods_2023_8==0, missing
	tab floods_2023_5 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_6 if floods_2023_8==0, missing
	tab floods_2023_6 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_7 if floods_2023_8==0, missing
	tab floods_2023_7 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_88 if floods_2023_8==0, missing
	tab floods_2023_88 if floods_2023_8==0, missing

	svy linearized: tab floods_2023_99 if floods_2023_8==0, missing
	tab floods_2023_99 if floods_2023_8==0, missing
	
	*type of 2022 flood impact 
	svy linearized: tab floods_2022_1 if floods_2022_8==0, missing
	tab floods_2022_1 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_1b if floods_2022_8==0, missing
	tab floods_2022_1b if floods_2022_8==0, missing

	svy linearized: tab floods_2022_2 if floods_2022_8==0, missing
	tab floods_2022_2 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_3 if floods_2022_8==0, missing
	tab floods_2022_3 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_4 if floods_2022_8==0, missing
	tab floods_2022_4 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_5 if floods_2022_8==0, missing
	tab floods_2022_5 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_6 if floods_2022_8==0, missing
	tab floods_2022_6 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_7 if floods_2022_8==0, missing
	tab floods_2022_7 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_88 if floods_2022_8==0, missing
	tab floods_2022_88 if floods_2022_8==0, missing

	svy linearized: tab floods_2022_99 if floods_2022_8==0, missing
	tab floods_2022_99 if floods_2022_8==0, missing
	
	*fear of husband
	svy linearized: tab fear_of_husband, missing
	tab fear_of_husband, missing
	
	*believe husband is justified in beating wife
	svy linearized: tab justification_for_hitting, missing
	tab justification_for_hitting, missing
	
	*husband has ever beat you
	svy linearized: tab husband_violence, missing
	tab husband_violence, missing
	
	*seek help
	svy linearized: tab seeking_help, missing
	tab seeking_help, missing
	
	*feel safe when home alone after dark
	svy linearized: tab home_safety_dark, missing
	tab home_safety_dark, missing

	*feel safe when in neighborhood alone after dark
	svy linearized: tab neighborhood_safety_dark, missing
	tab neighborhood_safety_dark, missing
	
	*experiences of discrimination 
	svy linearized: tab any_discrim, missing
	tab any_discrim, missing	
	
	*discrimination reason
	svy linearized: tab discrim_ethnic if any_discrim==1
	tab discrim_ethnic if any_discrim==1
	
	svy linearized: tab discrim_immigration if any_discrim==1
	tab discrim_immigration if any_discrim==1
	
	svy linearized: tab discrim_sex if any_discrim==1
	tab discrim_sex if any_discrim==1
	
	svy linearized: tab discrim_sexual_orientation if any_discrim==1
	tab discrim_sexual_orientation if any_discrim==1
	
	svy linearized: tab discrim_age if any_discrim==1
	tab discrim_age if any_discrim==1
	
	svy linearized: tab discrim_religion if any_discrim==1
	tab discrim_religion if any_discrim==1
	
	svy linearized: tab discirm_disability if any_discrim==1
	tab discirm_disability if any_discrim==1
	
	svy linearized: tab discrimination_reason if any_discrim==1
	tab discrimination_reason if any_discrim==1
	
	*asset index
	svy linearized: tab asset_quintile_update
	tab asset_quintile_update
	
	
*table three- child development by refugee status, primary school maternal education, and rural/urban area 
*----------------------------------------------	

*set child weights	
svyset [pweight=child_weights]

*child development <3 by refugee status 
svy linearized: mean Z_OVERALL if refugee_yn_enums==1
svy linearized: mean Z_OVERALL if refugee_yn_enums==2
svy linearized: regress Z_OVERALL refugee_yn_enums

svy linearized: mean Z_LANG if refugee_yn_enums==1
svy linearized: mean Z_LANG if refugee_yn_enums==2
svy linearized: regress Z_LANG refugee_yn_enums

svy linearized: mean Z_MOT if refugee_yn_enums==1
svy linearized: mean Z_MOT if refugee_yn_enums==2
svy linearized: regress Z_MOT refugee_yn_enums

svy linearized: mean Z_SEM if refugee_yn_enums==1
svy linearized: mean Z_SEM if refugee_yn_enums==2
svy linearized: regress Z_SEM refugee_yn_enums

svy linearized: mean Z_COG if refugee_yn_enums==1
svy linearized: mean Z_COG if refugee_yn_enums==2
svy linearized: regress Z_COG refugee_yn_enums

*child development >3 by refugee status
svy linearized: mean AIMECD_DA if refugee_yn_enums==1
svy linearized: mean AIMECD_DA if refugee_yn_enums==2
svy linearized: regress AIMECD_DA refugee_yn_enums
	
svy linearized: mean early_numeracy if refugee_yn_enums==1
svy linearized: mean early_numeracy if refugee_yn_enums==2
svy linearized: regress early_numeracy refugee_yn_enums

svy linearized: mean early_literacy if refugee_yn_enums==1
svy linearized: mean early_literacy if refugee_yn_enums==2
svy linearized: regress early_literacy refugee_yn_enums
	
svy linearized: mean executive_functioning if refugee_yn_enums==1
svy linearized: mean executive_functioning if refugee_yn_enums==2
svy linearized: regress executive_functioning refugee_yn_enums
	
svy linearized: mean social_emotional if refugee_yn_enums==1
svy linearized: mean social_emotional if refugee_yn_enums==2
svy linearized: regress social_emotional refugee_yn_enums

*child development <3 by primary education
svy linearized: mean Z_OVERALL if primary_ed==1
svy linearized: mean Z_OVERALL if primary_ed==0
svy linearized: regress Z_OVERALL primary_ed

svy linearized: mean Z_LANG if primary_ed==1
svy linearized: mean Z_LANG if primary_ed==0
svy linearized: regress Z_LANG primary_ed

svy linearized: mean Z_MOT if primary_ed==1
svy linearized: mean Z_MOT if primary_ed==0
svy linearized: regress Z_MOT primary_ed

svy linearized: mean Z_SEM if primary_ed==1
svy linearized: mean Z_SEM if primary_ed==0
svy linearized: regress Z_SEM primary_ed

svy linearized: mean Z_COG if primary_ed==1
svy linearized: mean Z_COG if primary_ed==0
svy linearized: regress Z_COG primary_ed

*child development >3 by primary education
svy linearized: mean AIMECD_DA if primary_ed==1
svy linearized: mean AIMECD_DA if primary_ed==0
svy linearized: regress AIMECD_DA primary_ed

svy linearized: mean early_numeracy if primary_ed==1
svy linearized: mean early_numeracy if primary_ed==0
svy linearized: regress early_numeracy primary_ed

svy linearized: mean early_literacy if primary_ed==1
svy linearized: mean early_literacy if primary_ed==0
svy linearized: regress early_literacy primary_ed

svy linearized: mean executive_functioning if primary_ed==1
svy linearized: mean executive_functioning if primary_ed==0
svy linearized: regress executive_functioning primary_ed

svy linearized: mean social_emotional if primary_ed==1
svy linearized: mean social_emotional if primary_ed==0
svy linearized: regress social_emotional primary_ed

*child development <3 by urban/rural
svy linearized: mean Z_OVERALL if rural==1
svy linearized: mean Z_OVERALL if rural==0
svy linearized: regress Z_OVERALL rural

svy linearized: mean Z_LANG if rural==1
svy linearized: mean Z_LANG if rural==0
svy linearized: regress Z_LANG rural

svy linearized: mean Z_MOT if rural==1
svy linearized: mean Z_MOT if rural==0
svy linearized: regress Z_MOT rural

svy linearized: mean Z_SEM if rural==1
svy linearized: mean Z_SEM if rural==0
svy linearized: regress Z_SEM rural

svy linearized: mean Z_COG if rural==1
svy linearized: mean Z_COG if rural==0
svy linearized: regress Z_COG rural

*child development >3 by urban/rural
svy linearized: mean AIMECD_DA if rural==1
svy linearized: mean AIMECD_DA if rural==0
svy linearized: regress AIMECD_DA rural

svy linearized: mean early_numeracy if rural==1
svy linearized: mean early_numeracy if rural==0
svy linearized: regress early_numeracy rural

svy linearized: mean early_literacy if rural==1
svy linearized: mean early_literacy if rural==0
svy linearized: regress early_literacy rural

svy linearized: mean executive_functioning if rural==1
svy linearized: mean executive_functioning if rural==0
svy linearized: regress executive_functioning rural

svy linearized: mean social_emotional if rural==1
svy linearized: mean social_emotional if rural==0
svy linearized: regress social_emotional rural

	
*table four a- Maternal Mental Health by Refugee Status, Education, and Area of Residence for Households with Child <3
*----------------------------------------------		

*set child weights	
svyset [pweight=child_weights]

*depression
svy linearized: tab depress refugee_yn_enums if agegroup==1, column
svy linearized: tab depress primary_ed if agegroup==1, column
svy linearized: tab depress rural if agegroup==1, column
  
*anxiety
svy linearized: tab anxiety refugee_yn_enums if agegroup==1, column
svy linearized: tab anxiety primary_ed if agegroup==1, column
svy linearized: tab anxiety rural if agegroup==1, column

*parenting stress
svy linearized: mean stress_cont if refugee_yn_enums==1 & agegroup==1
svy linearized: mean stress_cont if refugee_yn_enums==2 & agegroup==1
svy linearized: regress stress_cont refugee_yn_enums if agegroup==1

svy linearized: mean stress_cont if primary_ed==0 & agegroup==1
svy linearized: mean stress_cont if primary_ed==1 & agegroup==1
svy linearized: regress stress_cont primary_ed if agegroup==1

svy linearized: mean stress_cont if rural==0 & agegroup==1
svy linearized: mean stress_cont if rural==1 & agegroup==1
svy linearized: regress stress_cont rural if agegroup==1
	
*table four b- Maternal Mental Health by Refugee Status, Education, and Area of Residence for Households with Child 3+
*----------------------------------------------			

*set child weights	
svyset [pweight=child_weights]

*depression
svy linearized: tab depress refugee_yn_enums if agegroup==2, column
svy linearized: tab depress primary_ed if agegroup==2, column
svy linearized: tab depress rural if agegroup==2, column

*anxiety
svy linearized: tab anxiety refugee_yn_enums if agegroup==2, column
svy linearized: tab anxiety primary_ed if agegroup==2, column
svy linearized: tab anxiety rural if agegroup==2, column

*parenting stress
svy linearized: mean stress_cont if refugee_yn_enums==1 & agegroup==2
svy linearized: mean stress_cont if refugee_yn_enums==2 & agegroup==2
svy linearized: regress stress_cont refugee_yn_enums if agegroup==2
		
svy linearized: mean stress_cont if primary_ed==0 & agegroup==2
svy linearized: mean stress_cont if primary_ed==1 & agegroup==2
svy linearized: regress stress_cont primary_ed if agegroup==2

svy linearized: mean stress_cont if rural==0 & agegroup==2
svy linearized: mean stress_cont if rural==1 & agegroup==2
svy linearized: regress stress_cont rural if agegroup==2		
		
		
*table five- Pairwise correlations between stressors and maternal parenting stress, depression, and anxiety 
*----------------------------------------------			

	*set weights
	svyset [pweight=hh_weights]	
	
	*correlation between food insecurity & mental health conditions
	pwcorr food_worries healthy_food_access limited_food_choices meal_skipping eating_less food_shortage hunger_without_eating whole_day_without_eating food_insecure depress_cont anxiety_cont stress_cont, sig star(0.05)	
	
	*correlation between flooding & mental health conditions
	pwcorr flood_2023_impact flood_2022_impact depress_cont anxiety_cont stress_cont, sig star(0.05)

	*correlation between domestic violence & mental health conditions
	pwcorr depress_cont anxiety_cont stress_cont fear_of_husband justification_for_hitting husband_violence seeking_help, sig star(0.05)

	*correlation between crime & mental health conditions
	pwcorr neighborhood_safe home_safe crime_3yr depress_cont anxiety_cont stress_cont if home_safe<=4, sig star(0.05)

	*correlation between discrimination & mental health conditions
	pwcorr any_discrim depress_cont anxiety_cont stress_cont, sig star(0.05)

	*correlation between asset quintile & mental health conditions
	pwcorr asset_quintile depress_cont anxiety_cont stress_cont, sig star(0.05)
	

*figure six- Prevalence and co-occurrence of maternal mental health conditions by age group 
*----------------------------------------------		

	*set weights
	svyset [pweight=child_weights]	
	
	*inputs to venn diagrams
	svy linearized: tab only_depress agegroup, column
	svy linearized: tab only_anxiety agegroup, column
	svy linearized: tab only_stress agegroup, column

	svy linearized: tab depress_anxiety agegroup, column
	svy linearized: tab depress_stress agegroup, column
	svy linearized: tab anxiety_stress agegroup, column

	svy linearized: tab anxiety_stress_depress agegroup, column
	svy linearized: tab no_SDA agegroup, column
	

*table six- Average child development by various maternal mental health co-occurances 
*----------------------------------------------	
	
	*set weights
	svyset [pweight=child_weights]	
	
	*average ECD <3 by various mental health combinations
	svy linearized: mean Z_OVERALL if no_SDA==1
	svy linearized: mean Z_OVERALL if only_depress==1
	svy linearized: mean Z_OVERALL if only_anxiety==1
	svy linearized: mean Z_OVERALL if only_stress==1
	svy linearized: mean Z_OVERALL if depress_anxiety==1
	svy linearized: mean Z_OVERALL if depress_stress==1
	svy linearized: mean Z_OVERALL if anxiety_stress==1
	svy linearized: mean Z_OVERALL if anxiety_stress_depress==1
	
	*average ECD 3+ by various mental health combinations
	svy linearized: mean AIMECD_DA if no_SDA==1
	svy linearized: mean AIMECD_DA if only_depress==1
	svy linearized: mean AIMECD_DA if only_anxiety==1
	svy linearized: mean AIMECD_DA if only_stress==1
	svy linearized: mean AIMECD_DA if depress_anxiety==1
	svy linearized: mean AIMECD_DA if depress_stress==1
	svy linearized: mean AIMECD_DA if anxiety_stress==1
	svy linearized: mean AIMECD_DA if anxiety_stress_depress==1
	
*table seven- Individual Linear Regression Results of Parenting Stress, Depression, and Anxiety on ECD <3 
*----------------------------------------------	
	
	*set weights
	svyset [pweight=child_weights] 
	
	*individual regression analyses
	svy linearized: regress Z_OVERALL stress_cont 

	svy linearized: regress Z_OVERALL stress_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status

	svy linearized: regress Z_OVERALL depress_cont 

	svy linearized: regress Z_OVERALL depress_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status

	svy linearized: regress Z_OVERALL anxiety_cont 

	svy linearized: regress Z_OVERALL anxiety_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status
	
*table eight- Individual Linear Regression Results of Parenting Stress, Depression, and Anxiety on ECD 3+ 
*----------------------------------------------	
	
	*set weights
	svyset [pweight=child_weights] 
	
	*individual regression analyses

	svy linearized: regress AIMECD_DA stress_cont AGE

	svy linearized: regress AIMECD_DA stress_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status attend_ece 

	svy linearized: regress AIMECD_DA depress_cont AGE

	svy linearized: regress AIMECD_DA depress_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status attend_ece

	svy linearized: regress AIMECD_DA anxiety_cont AGE

	svy linearized: regress AIMECD_DA anxiety_cont food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status attend_ece

	
*table nine- Linear Regression Results of Depression, Anxiety, and Parenting Stress Interaction on ECD <3
*----------------------------------------------	

	*set weights
	svyset [pweight=child_weights] 
	
	*triple interaction regression weighted and unweighted
	svy linearized: regress Z_OVERALL c.depress_cont##c.stress_cont##c.anxiety_cont

	svy linearized: regress Z_OVERALL food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status c.depress_cont##c.stress_cont##c.anxiety_cont
	
	
*table ten- Linear Regression Results of Depression, Anxiety, and Parenting Stress Interaction on ECD 3+
*----------------------------------------------	

	*set weights
	svyset [pweight=child_weights] 
	
	*triple interaction regression weighted and unweighted
	svy linearized: regress AIMECD_DA c.depress_cont##c.stress_cont##c.anxiety_cont

	svy linearized: regress AIMECD_DA  food_insecure flood_impact_gen fear_of_husband asset_quintile maternal_ed_cat fetch_child_gender AGE refugee_status c.depress_cont##c.stress_cont##c.anxiety_cont
	
*table eleven- Linear predictions of child development by maternal mental health & figure 7- Adjusted Prediction of Child Development <3 at Varying Levels of Maternal Mental Health
*----------------------------------------------	
	
	*set weights
	svyset [pweight=child_weights] 

	*triple interaction regression for children <3 
	svy linearized: regress Z_OVERALL c.depress_cont##c.stress_cont##c.anxiety_cont

	label var anxiety_cont "Maternal Anxiety"
	label var stress_cont "Maternal Parenting Stress"

	*four global macros 
	*max depression=20
	*max anxiety=21
	*stress max=25
	sum depress_cont, detail
	sum anxiety_cont, detail

	/* determined high, low, and median values for anxiety */
	global Hanxiety=21
	global Lanxiety=0
	global Manxiety=4

	sum stress_cont, detail

	/* determine high, low, and median values for stress */
	global Hstress=25
	global Lstress=0
	global Mstress=6

	/* determine high, low, and median values for depression */
	global Hdepress=20
	global Ldepress=0
	global Mdepress=6


	/* margins & margin plot at median levels */
	margins, at(anxiety_cont=(0 4) depress_cont=($Mdepress $Ldepress) stress_cont=($Mstress $Lstress)) vsquish

	marginsplot,  xtitle("Maternal Anxiety") ytitle("Linear Prediction of Child Development") legend(label(1 "No Maternal Depression or Stress") label(2 "No Maternal Depression, Median Maternal Stress") label(3 "Median Maternal Depression, No Maternal Stress") label (4 "Median Maternal Depression and Stress"))
	
*table eleven- Linear predictions of child development by maternal mental health & figure 8- Adjusted Prediction of Child Development 3+ at Varying Levels of Maternal Mental Health
*----------------------------------------------	

	*set weights
	svyset [pweight=child_weights] 

	*triple interaction regression for children <3 
	svy linearized: regress AIMECD_DA c.depress_cont##c.stress_cont##c.anxiety_cont

	label var anxiety_cont "Maternal Anxiety"
	label var stress_cont "Maternal Parenting Stress"

	*four global macros 
	*max depression=20
	*max anxiety=21
	*stress max=25
	sum depress_cont, detail
	sum anxiety_cont, detail

	/* determined high, low, and median values for anxiety */
	global Hanxiety=21
	global Lanxiety=0
	global Manxiety=4

	sum stress_cont, detail

	/* determine high, low, and median values for stress */
	global Hstress=25
	global Lstress=0
	global Mstress=6

	/* determine high, low, and median values for depression */
	global Hdepress=20
	global Ldepress=0
	global Mdepress=6


	/* margins & margin plot at median levels */
	margins, at(anxiety_cont=(0 4) depress_cont=($Mdepress $Ldepress) stress_cont=($Mstress $Lstress)) vsquish

	marginsplot,  xtitle("Maternal Anxiety") ytitle("Linear Prediction of Child Development") 
	











